"""
:authors: Superior_6564
:license: Apache License, Version 2.0, see LICENSE file
:copyright: (c) 2022 Superior_6564
"""


# import degget
# import games_help
# import packages
from degget import show
from games_help import gen_ru_words
from packages import install, pip_upgrade, required

__author__ = 'Superior_6564'
__version__ = '0.0.3'
__email__ = 'vip.klochayil@gmail.com'



"""
:authors: Superior_6564
:license: Apache License, Version 2.0, see LICENSE file
:copyright: (c) 2022 Superior_6564
"""


import os


def show():
    if os.getcwd() == "/content":
        from google.colab.patches import cv2_imshow as imshow
        import cv2
        import requests
        photo_1 = requests.get('https://user-images.githubusercontent.com/100136305/190876998-74c4b591-67ee-458a-b720-ec9e59389cee.jpg')
        out_1 = open("degget_6564.jpeg", "wb")
        out_1.write(photo_1.content)
        out_1.close()
        degget_img = cv2.imread(r"/content/degget_6564.jpeg")
        imshow(degget_img)
    else:
        print("Данный метод работает только в Google Colab")



"""
:authors: Superior_6564
:license: Apache License, Version 2.0, see LICENSE file
:copyright: (c) 2022 Superior_6564
"""


import subprocess
import sys
import os


def install(package):
    subprocess.check_call([sys.executable, "-m", "pip", "install", package])
    subprocess.check_call([sys.executable, "-m", "pip", "install", "--upgrade", package])
    if os.getcwd() == "/content":
        package = "pip show " + package
        get_ipython().system(package)


def pip_upgrade():
    subprocess.check_call([sys.executable, "-m", "pip", "install", "--upgrade", "pip"])


def required():
    print("Установка необходимых библиотек")
    install("requests")
    print("Установка завершена")



#!/usr/bin/env python

from io import open
from setuptools import setup

"""
:authors: Superior_6564
:license: Apache License, Version 2.0, see LICENSE file
:copyright: (c) 2022 Superior_6564
"""

version = '0.0.3'

with open('README.md', encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='superior6564',
    version=version,

    author='Superior_6564',
    author_email='vip.klochayil@gmail.com',

    description=(
        u'This my first library uploaded to the Internet for testing.'
        u'\nBefore using you need to run packages.required()'
    ),
    long_description=long_description,
    # long_description_content_type='text/markdown',

    url='https://github.com/Superior-GitHub/Superior6564',
    download_url='https://github.com/Superior-GitHub/Superior6564/archive/refs/heads/main.zip'.format(
        version
    ),

    license='Apache License, Version 2.0, see LICENSE file',

    packages=['superior6564'],
    install_requires=['', ''],

    classifiers=[
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: OS Independent',
        'Intended Audience :: End Users/Desktop',
        'Intended Audience :: Developers',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ]
)
